pub struct CoreArgs { /* private fields */ }Expand description
Core command-line arguments shared between lingora-cli and lingora-tui.
These arguments represent settings that can be overridden when running
lingora-cli and lingora-tui from the command line. They allow users to:
- Point to a specific configuration file (or otherwise rely on auto-discovery of
Lingora.toml) - Supplement or override the translation files and locales defined by the configuration.
- Enable Rust source scanning for
dioxus_i18nmacro usage - Control how generated
I18nConfigcode includes locales