FluentDocument

Struct FluentDocument 

pub struct FluentDocument { /* private fields */ }
A normalized, representation of all Fluent translations for one locale.

FluentDocument aggregates entries from one or more ParsedFluentFiles belonging to the same locale (e.g. split files like en-GB/auth.ftl, en-GB/ui.ftl, en-GB/errors.ftl all for en-GB).

Implementations

Source

impl FluentDocument

pub fn from_parsed_files(locale: &Locale, files: &[ParsedFluentFile]) -> Self

Constructs a FluentDocument by merging entries from all ParsedFluentFiles that match the given locale.

pub fn locale(&self) -> &Locale

Returns the locale this document represents.

pub fn entry_identifiers(&self) -> impl Iterator<Item = QualifiedIdentifier>

Returns an iterator over all top-level qualified identifiers defined in this document.

pub fn all_identifiers(&self) -> impl Iterator<Item = QualifiedIdentifier>

Returns an iterator over all identifiers used or defined (including placeholders and references inside patterns).

pub fn duplicate_identifier_names( &self, ) -> impl Iterator<Item = QualifiedIdentifier>

Returns an iterator over identifiers that appear more than once in the document.

pub fn invalid_references(&self) -> impl Iterator<Item = QualifiedIdentifier>

Returns an iterator over identifiers that are referenced, e.g. { $var }, but not defined elsewhere in the document.

pub fn signature(&self, identifier: &QualifiedIdentifier) -> Option<&Signature>

Returns the placeholder signature (arguments/variables) for the given identifier, if it is defined in this document.

pub fn entries( &self, identifier: &QualifiedIdentifier, ) -> impl Iterator<Item = &Entry>

Returns an iterator over all AST Entry nodes that define the given identifier.